==> haskell-singleton-bool-0.1.5-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.5
visibility:           public
id:                   singleton-bool-0.1.5-HROmJ2x3IGbHtluHkmYgNW
key:                  singleton-bool-0.1.5-HROmJ2x3IGbHtluHkmYgNW
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  6a8a798c9d60c081ebfe2f73c6d786d2
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-8.10.4/site-local/singleton-bool-0.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/singleton-bool-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/singleton-bool-0.1.5
hs-libraries:         HSsingleton-bool-0.1.5-HROmJ2x3IGbHtluHkmYgNW
depends:              base-4.14.1.0 dec-0.0.3-Hc3UBFtWOTQ2yQiTsJahOK
haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.5-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.5
visibility:           public
id:                   singleton-bool-0.1.5-AMAzfSfuY3w2SeCcEcyHjl
key:                  singleton-bool-0.1.5-AMAzfSfuY3w2SeCcEcyHjl
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  d98d8ef2fa2bfc12298f74bdefb13a23
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-8.10.4/site-local/singleton-bool-0.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/singleton-bool-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/singleton-bool-0.1.5
hs-libraries:         HSsingleton-bool-0.1.5-AMAzfSfuY3w2SeCcEcyHjl
depends:              base-4.14.1.0 dec-0.0.4-3AE42aONIQcIR6v29GI9ZS
haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
